==> kom%2B%2B-0.2.tar.gz: kom++-0.2/libconnection/009get_membership_q.cc <==
// Get membership.
//
// $Id: 009get_membership_q.cc,v 1.8 1994/07/16 17:32:56 ceder Exp $
// Copyright (C) 1994  Per Cederqvist and Inge Wallin
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

#include <iostream.h>
#include <assert.h>
#include "prot-a-LyStr.h"
#include "get_membership_q.h"
#include "connection.h"
#include "membership.h"
    
get_membership_question::get_membership_question(Connection *conn, 
						 Pers_no pno, Conf_no cno)
    : question(conn), membership(NULL)
{
    prot_a_LyStr   s;

    s << ref_no() << " 9 " << pno << ' ' << cno << '\n';
    port->send_question(s);
}


get_membership_question::~get_membership_question()
{
    if (membership != NULL)
	delete membership;
}


void
get_membership_question::parser(prot_a_LyStr &str)
{
    membership = new Membership(str);

    state = st_ok;
    deallocate_refno();
}


Membership
get_membership_question::result()
{
    return *membership;
}

==> kom%2B%2B-0.3.tar.gz: kom++-0.3/libconnection/009get_membership_q.cc <==
// Get membership.
//
// $Id: 009get_membership_q.cc,v 1.9 1994/07/30 22:12:04 inge Exp $
// Copyright (C) 1994  Per Cederqvist and Inge Wallin
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

#include <iostream.h>
#include <assert.h>
#include "prot-a-LyStr.h"
#include "get_membership_q.h"
#include "connection.h"
#include "membership.h"
    
get_membership_question::get_membership_question(Connection *conn, 
						 Pers_no pno, Conf_no cno)
    : question(conn), membership(), pers_no(pno)
{
    prot_a_LyStr   s;

    s << ref_no() << " 9 " << pno << ' ' << cno << '\n';
    port->send_question(s);
}


get_membership_question::~get_membership_question()
{
}


void
get_membership_question::parser(prot_a_LyStr &str)
{
    membership = Membership(pers_no, str);

    state = st_ok;
    deallocate_refno();
}


Membership
get_membership_question::result()
{
    return membership;
}
